
# Slot: apply_to




URI: [linkml:slot_definition_apply_to](https://w3id.org/linkml/slot_definition_apply_to)


## Domain and Range

[SlotDefinition](SlotDefinition.md) &#8594;  <sub>0..\*</sub> [SlotDefinition](SlotDefinition.md)

## Parents

 *  is_a: [apply_to](apply_to.md)

## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
